/*
 * Copyright 2023 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef I2CDEVICE_H
#define I2CDEVICE_H

#include <QObject>
#include <QVector>

#include "devicepowerinfo.h"

#define I2C_DEVICE_PATH "/sys/bus/i2c/devices/"
class I2cDevice : public QObject
{
    Q_OBJECT
public:
    explicit I2cDevice(QObject *parent = nullptr);

signals:

private:
    QVector<DevicePowerInfo *> m_devicePowerInfo;

    QString m_controlFile;

    void getDevicePowerInfo();
    bool deviceHasRuntimePM(const QString &devPath);
    QString getI2cDeviceName(const QString &devPath);

public:
    int getPCIDeviceNum();
    QString getDeviceName(int deviceIndex);
    QString getCurrentPowerStat(int deviceIndex);
    QString getDefaultPowerStat(int deviceIndex);

    bool setPowerStat(int deviceIndex, const QString &stat);
    bool setAllDevicePowerStat(const QString &stat);
    void printAllDeviceInfo();
};

#endif // I2CDEVICE_H
